//
//  View.swift
//  DatePicker
//
//  Created by Mark Meretzky on 9/17/14.
//  Copyright (c) 2014 Mark Meretzky. All rights reserved.
//

import UIKit;

class View: UIView {
	let dateFormatter: NSDateFormatter = NSDateFormatter();
	let datePicker: UIDatePicker = UIDatePicker();
	let label: UILabel = UILabel();

	required init(coder aDecoder: NSCoder) {
		// Initialization code
		super.init(coder: aDecoder);
		backgroundColor = UIColor.whiteColor();

		//Lots of details, including day of week and time zone.
		dateFormatter.dateStyle = NSDateFormatterStyle.FullStyle; //vs. .NoStyle
		dateFormatter.timeStyle = NSDateFormatterStyle.FullStyle;

		datePicker.backgroundColor = UIColor.yellowColor();
		datePicker.datePickerMode = UIDatePickerMode.Date; //vs. UIDatePickerMode.Time
		datePicker.minuteInterval = 1;                     //or try 15
		datePicker.setTranslatesAutoresizingMaskIntoConstraints(false);

		datePicker.addTarget(self,
			action: "valueChanged:",
			forControlEvents: UIControlEvents.ValueChanged);

		addSubview(datePicker);

		label.backgroundColor = UIColor.orangeColor();
		label.font = UIFont.systemFontOfSize(22);	//same as date picker's font
		label.textAlignment = NSTextAlignment.Center;
		label.numberOfLines = 0;	//0 means no limit
		label.lineBreakMode = NSLineBreakMode.ByWordWrapping;
		label.setTranslatesAutoresizingMaskIntoConstraints(false);
		addSubview(label);

		valueChanged(datePicker);	//Put text into the label.

		/*
		Keep the date picker centered horizontally.
		I.e., keep the x coordinate of the center of the date picker
		equal to the x coordinate of the center of the View.
		*/
		addConstraint(NSLayoutConstraint(
			item: datePicker,
			attribute: NSLayoutAttribute.CenterX,
			relatedBy: NSLayoutRelation.Equal,
			toItem: self,
			attribute: NSLayoutAttribute.CenterX,
			multiplier: 1,
			constant: 0));
		
		/*
		Keep the label centered horizontally.
		I.e., keep the x coordinate of the center of the label
		equal to the x coordinate of the center of the View.
		*/
		addConstraint(NSLayoutConstraint(
			item: label,
			attribute: NSLayoutAttribute.CenterX,
			relatedBy: NSLayoutRelation.Equal,
			toItem: self,
			attribute: NSLayoutAttribute.CenterX,
			multiplier: 1,
			constant: 0));
		
		/*
		Keep the top edge of the label pressing against the bottom edge of the date picker.
		I.e., keep the y coordinate of the top edge of the label equal to the y coordinate
		of the bottom edge of the date picker, with a margin of 8 pairs of pixels.
		*/
		addConstraint(NSLayoutConstraint(
			item: label,
			attribute: NSLayoutAttribute.Top,
			relatedBy: NSLayoutRelation.Equal,
			toItem: datePicker,
			attribute: NSLayoutAttribute.Bottom,
			multiplier: 1,
			constant: 8));
		
		//Keep the width of the label equal to the width of the date picker.
		
		addConstraint(NSLayoutConstraint(
			item: label,
			attribute: NSLayoutAttribute.Width,
			relatedBy: NSLayoutRelation.Equal,
			toItem: datePicker,
			attribute: NSLayoutAttribute.Width,
			multiplier: 1,
			constant: 0));
	}

	/*
	We're not allowed to use viewController.topLayoutGuide until a refernce to this View
	has been stored into the view property of the view controller.  That's why this final
	constraint has to be added in a separate method, called from the viewDidLoad method of
	the view controller.
	*/

	func addViewControllerConstraint(viewController: ViewController) {
		/*
		The bottom edge of the top layout guide is the lower edge of the status bar
		if the status bar is visible, or the top edge of the View if the status bar is
		invisible.  Keep the height of the top edge of the date picker equal to the
		height of the bottom edge of the top layout guide.
		*/
		addConstraint(NSLayoutConstraint(
			item: datePicker,
			attribute: NSLayoutAttribute.Top,
			relatedBy: NSLayoutRelation.Equal,
			toItem: viewController.topLayoutGuide,
			attribute: NSLayoutAttribute.Bottom,
			multiplier: 1,
			constant: 0));
	}

	func valueChanged(datePicker: UIDatePicker!) {
		label.text = dateFormatter.stringFromDate(datePicker.date);
	}

	/*
	// Only override drawRect: if you perform custom drawing.
	// An empty implementation adversely affects performance during animation.
	override func drawRect(rect: CGRect)
	{
		// Drawing code
	}
	*/

}
